/* ************************************************************************** */
/*                                       _____           _                    */
/*  libp7.h                             |_   _|__  _   _| |__   ___ _   _     */
/*  | Project : libp7                     | |/ _ \| | | | '_ \ / _ \ | | |    */
/*                                        | | (_) | |_| | | | |  __/ |_| |    */
/*  By: thomas <thomas@touhey.fr>         |_|\___/ \__,_|_| |_|\___|\__, |.fr */
/*  Last updated: 2016/05/12 01:15:03                               |___/     */
/*                                                                            */
/* ************************************************************************** */

#ifndef LIBP7_H
# define LIBP7_H
# include <stdio.h>

/* ************************************************************************** */
/*  libp7 errors                                                              */
/* ************************************************************************** */
/* Enumeration */
/* - Whenever you add/remove errors, think about updating core/geterror ! - */
typedef enum {
	p7_noerror,

	/* errors caused by libusb or libusb usage */
	p7_error_uninitialized,
	p7_error_libusb,
	p7_error_nocalc,
	p7_error_noaccess,
	p7_error_timeout,
	p7_error_checksum,

	/* user interface */
	p7_error_noseek,
	p7_error_filename,
	p7_error_dirname,
	p7_error_overwrite_impossible,
	p7_error_fullmem,
	p7_error_denied_overwrite,

	/* others */
	p7_error_internal,
	p7_error_unknown
} p7_error_t;

/* Last error global */
extern int p7_error;

/* Message getting function */
char *p7_geterror(void);

/* ************************************************************************** */
/*  Validating stuff                                                          */
/* ************************************************************************** */
/* Filename and dirname */
int p7_validate_filename(const char *filename);
int p7_validate_dirname(const char *dirname);

/* ************************************************************************** */
/*  Core functions                                                            */
/* ************************************************************************** */
/* Initialization */
int p7_init(void);

/* - Nothing for the de-initialization, thanks to atexit magic - */
/* ************************************************************************** */
/*  Protocol                                                                  */
/* ************************************************************************** */
/* Initializer and terminator */
int p7_start(void);
int p7_term(void);

/* Get info */
int p7_getusername(char *username);

/* Send or request file */
int p7_sendstream(FILE *file, unsigned int size, char *dirname, char *filename,
	char *devname, int overwrite, int (*ow_conf)(void));
int p7_sendfile(FILE *file, char *dirname, char *filename, char *devname,
	int overwrite, int (*ow_conf)(void));
int p7_reqfile(FILE *file, char *dirname, char *filename, char *devname);

/* Delete distant file */
int p7_delfile(char *dirname, char *filename, char *devname);

/* Copy file on distant device */
int p7_copyfile(char *dirname, char *filename, char *newdir, char *newname,
	char *devname);

#endif /* LIBP7_H */
