/* ************************************************************************** */
/*                                       _____           _                    */
/*  libp7/internals.h                   |_   _|__  _   _| |__   ___ _   _     */
/*  | Project : libp7                     | |/ _ \| | | | '_ \ / _ \ | | |    */
/*                                        | | (_) | |_| | | | |  __/ |_| |    */
/*  By: thomas <thomas@touhey.fr>         |_|\___/ \__,_|_| |_|\___|\__, |.fr */
/*  Last updated: 2016/05/12 01:16:06                               |___/     */
/*                                                                            */
/* ************************************************************************** */

#ifndef LIBP7_INTERNALS_H
# define LIBP7_INTERNALS_H
# include <libp7.h>
# include <libusb-1.0/libusb.h>

/* Buffer sizes */
# define MAX_RAWDATA_SIZE 256
/* - id + total + data - */
# define MAX_RAWDFLD_SIZE (8 + MAX_RAWDATA_SIZE)
/* - id + total + encoded data - */
# define MAX_ENCDFLD_SIZE (8 + (MAX_RAWDATA_SIZE * 2))
/* - t + st + ext + d field + checksum + null byte - */
# define MAX_PACKET_SIZE (8 + MAX_ENCDFLD_SIZE + 2 + 1)

/* The following values are defined in fxReverse project documentation */
# define ACTIVE_TIMEOUT (10 * 1000) /* 10 seconds */
# define PASSVE_TIMEOUT (6 * 60 * 1000) /* 6 minutes */
# define SENDNG_TIMEOUT (2000) /* 2 seconds (exp. value used in UC) */

/* libusb endpoints */
# define ENDPOINT_OUT (LIBUSB_ENDPOINT_OUT | LIBUSB_TRANSFER_TYPE_ISOCHRONOUS)
# define ENDPOINT_IN (LIBUSB_ENDPOINT_IN | LIBUSB_TRANSFER_TYPE_BULK)

/* ************************************************************************** */
/*  Packet I/O                                                                */
/* ************************************************************************** */
/* Main functions */
# include <libp7/packetio.h>

/* Utilities */
int p7_send_basic(unsigned int type, unsigned int subtype, int resp);
int p7_send_ext(unsigned int type, unsigned int subtype,
	void *data, unsigned int size, int resp);
int p7_send_again(void);
int p7_recv(unsigned char *lastbuf, int lastbuf_size);

/* Resend error packet (meant to be used with recv, not suited for public) */
int p7_send_err_resend(unsigned char *lastbuf, int lastbuf_size);

/* ************************************************************************** */
/*  Useful globals                                                            */
/* ************************************************************************** */
/* Device handler */
extern libusb_device_handle *p7_lusb_handler;

/* Is active */
extern int p7_active;

/* Is shifted */
extern int p7_shifted;

/* last sent command */
extern unsigned int p7_last_sent_command;

/* ************************************************************************** */
/*  Buffers                                                                   */
/* ************************************************************************** */
/* raw sending packet buffers */
extern unsigned char *p7_send_buffers[2];
extern int p7_send_buffers_size[2];
extern int p7_send_buffer_id;
/* raw reception packet buffer */
extern unsigned char *p7_recv_buffer;

/* active response */
# define response (*p7_response)

/* ************************************************************************** */
/*  Utilities                                                                 */
/* ************************************************************************** */
/* Encoding/decoding functions */
unsigned int p7_encode(void *fnal, void *raw, unsigned int size);
unsigned int p7_decode(void *fnal, void *encoded, unsigned int size);

/* Checksum function */
unsigned int p7_checksum(uint8_t *packet, unsigned int size);

/* ASCII-hex utilities */
void p7_putascii(unsigned char *p, unsigned int i, int n);
unsigned int p7_getascii(unsigned char *p, int n);

# include <libp7/internals/log.h>
#endif
