/* ************************************************************************** */
/*                                       _____           _                    */
/*  libp7/internals/log.h               |_   _|__  _   _| |__   ___ _   _     */
/*  | Project : libp7                     | |/ _ \| | | | '_ \ / _ \ | | |    */
/*                                        | | (_) | |_| | | | |  __/ |_| |    */
/*  By: thomas <thomas@touhey.fr>         |_|\___/ \__,_|_| |_|\___|\__, |.fr */
/*  Last updated: 2016/08/19 01:31:58                               |___/     */
/*                                                                            */
/* ************************************************************************** */

#ifndef LIBP7_INTERNALS_LOG_H
# define LIBP7_INTERNALS_LOG_H
# include <stdio.h>

/* ************************************************************************** */
/*  Log utility                                                               */
/* ************************************************************************** */
/* Log level */
# define ll_info 0
# define ll_warn 1
# define ll_error 2
# define ll_fatal 3
# define ll_none 4

/* Macros */
# define log(P, S, ...) fprintf(stderr, P "%s: " S "\n", __FUNCTION__, ##__VA_ARGS__)
# define logm(S, M, N) p7_log_mem(S, M, N)

# if LOGLEVEL <= ll_info
#  define log_info(S, ...) log("[libp7 info]  ", S, ##__VA_ARGS__)
#  define logm_info(M, N) logm("[libp7 info]  ", M, N)
# else
#  define log_info(S, ...)
#  define logm_info(M, N)
# endif

# if LOGLEVEL <= ll_warn
#  define log_warn(S, ...) log("[libp7 warn]  ", S, ##__VA_ARGS__)
#  define logm_warn(M, N) logm("[libp7 warn]  ", M, N)
# else
#  define log_warn(S, ...)
#  define logm_warn(M, N)
# endif

# if LOGLEVEL <= ll_error
#  define log_error(S, ...) log("[libp7 error] ", S, ##__VA_ARGS__)
# else
#  define log_error(S, ...)
# endif

# if LOGLEVEL <= ll_fatal
#  define log_fatal(S, ...) log("[libp7 fatal] ", S, ##__VA_ARGS__)
# else
#  define log_fatal(S, ...)
# endif

/* Functions prototypes */
void p7_log_mem(const char *prefix, void *m, size_t n);
long p7_get_ms(void);

/* ************************************************************************** */
/*  Get messages from codes                                                   */
/* ************************************************************************** */
const char *p7_getcmdstring(p7_commandcode_t code);
const char *p7_geterrstring(p7_errcode_t code);
const char *p7_gettermstring(p7_termtype_t code);
const char *p7_getowstring(p7_commandoverwrite_t code);

#endif /* LIBP7_INTERNALS_LOG_H */
