/* ************************************************************************** */
/*                                       _____           _                    */
/*  libp7/packetio.h                    |_   _|__  _   _| |__   ___ _   _     */
/*  | Project : libp7                     | |/ _ \| | | | '_ \ / _ \ | | |    */
/*                                        | | (_) | |_| | | | |  __/ |_| |    */
/*  By: thomas <thomas@touhey.fr>         |_|\___/ \__,_|_| |_|\___|\__, |.fr */
/*  Last updated: 2016/08/17 18:09:04                               |___/     */
/*                                                                            */
/* ************************************************************************** */

#ifndef LIBP7_PACKETIO_H
# define LIBP7_PACKETIO_H
# include <libp7/packet.h>

/* ************************************************************************** */
/*  Packet sending                                                            */
/* ************************************************************************** */
/* Commands */
int p7_send_cmdsys_reset(void);
int p7_send_cmdsys_getinfo(void);
int p7_send_cmdsys_setlink(unsigned int baudrate, int parity, int stopbits);
int p7_send_cmdfls_reqfile(char *dirname, char *filename, char *devname);
int p7_send_cmdfls_sendfile(p7_commandoverwrite_t ow, unsigned int fs,
	char *dirname, char *filename, char *devname);
int p7_send_cmdfls_delfile(char *dirname, char *filename, char *devname);
int p7_send_cmdfls_copyfile(char *dirname, char *filename,
	char *newdir, char *newname, char *devname);

/* Data */
int p7_send_data(unsigned int total, unsigned int id,
	void *data, unsigned int datasize, int resp);
int p7_send_data_quicker(unsigned int total, unsigned int id,
	void *buf, unsigned int datasize, int resp);

/* Errors */
int p7_send_err_overwrite_no(void);

/* Acknowledgements */
int p7_send_ack(int resp);
int p7_send_ack_confirm_ow(void);
int p7_send_ack_ext(void *data, unsigned int datasize);

/* Checks */
int p7_send_check(int initial);

/* Roleswap */
int p7_send_roleswp(void);

/* Terminations */
int p7_send_term(void);
int p7_send_term_usr(void);
int p7_send_term_timeout(void);
int p7_send_term_overwrite(void);

/* ************************************************************************** */
/*  Packet response                                                           */
/* ************************************************************************** */
/* active response */
extern p7_packet_t *p7_response;

/* Unshift (get response without sending) */
int p7_unshift(void);

#endif /* LIBP7_PACKETIO_H */
