/* ************************************************************************** */
/*                                       _____           _                    */
/*  packet/send_term.c                  |_   _|__  _   _| |__   ___ _   _     */
/*  | Project : libp7                     | |/ _ \| | | | '_ \ / _ \ | | |    */
/*                                        | | (_) | |_| | | | |  __/ |_| |    */
/*  By: thomas <thomas@touhey.fr>         |_|\___/ \__,_|_| |_|\___|\__, |.fr */
/*  Last updated: 2016/08/17 09:51:48                               |___/     */
/*                                                                            */
/* ************************************************************************** */

#include <libp7/internals.h>

/*
 *	Type and subtypes
 */

#define T p7_pt_terminate
#define ST_DEFAULT 0x00
#define ST_USRREQ 0x01
#define ST_TIMEOUTS 0x02
#define ST_OVERWRITE 0x03

/**
 *	p7_send_term:
 *	Send termination packet.
 *
 *	Terminates communication.
 *
 *	@return				if it worked
 */

int p7_send_term(void)
{
	return (p7_send_basic(T, ST_DEFAULT, 1));
}

/**
 *	p7_send_term_usr:
 *	Send user request termination packet.
 *
 *	@return				if it worked
 */

int p7_send_term_usr(void)
{
	return (p7_send_basic(T, ST_USRREQ, 1));
}

/**
 *	p7_send_term_timeout:
 *	Send timeouts termination packet.
 *
 *	@return				if it worked
 */

int p7_send_term_timeout(void)
{
	return (p7_send_basic(T, ST_TIMEOUTS, 1));
}

/**
 *	p7_send_term_overwrite:
 *	Send overwrite termination packet (terminate to deny overwrite).
 *
 *	@return				if it worked
 */

int p7_send_term_overwrite(void)
{
	return (p7_send_basic(T, ST_OVERWRITE, 1));
}
