/* ************************************************************************** */
/*                                       _____           _                    */
/*  protocol/copyfile.c                 |_   _|__  _   _| |__   ___ _   _     */
/*  | Project : libp7                     | |/ _ \| | | | '_ \ / _ \ | | |    */
/*                                        | | (_) | |_| | | | |  __/ |_| |    */
/*  By: thomas <thomas@touhey.fr>         |_|\___/ \__,_|_| |_|\___|\__, |.fr */
/*  Last updated: 2016/09/05 00:52:21                               |___/     */
/*                                                                            */
/* ************************************************************************** */

#include <libp7/internals.h>

/**
 *	p7_copyfile:
 *	Copies a file into another on distant device.
 *
 *	@arg	dirname		the directory name
 *	@arg	filename	the filename
 *	@arg	newdir		the new directory name
 *	@arg	newname		the new filename
 *	@arg	devname		the device name
 *	@return				if it worked
 */

int p7_copyfile(char *dirname, char *filename, char *newdir, char *newname,
	char *devname)
{
	/* check filenames */
	if (!p7_validate_filename(filename) || !p7_validate_filename(newname)) {
		p7_error = p7_error_filename;
		log_error("one of the sent filenames was crappy");
		return (0);
	}

	/* check dirnames */
	if ((dirname && !p7_validate_dirname(dirname))
	 || (newdir && !p7_validate_dirname(newdir))) {
		p7_error = p7_error_dirname;
		log_error("one of the sent dirnames was crappy");
		return (0);
	}

	/* send command packet */
	log_info("sending command");
	if (!p7_send_cmdfls_copyfile(dirname, filename, newdir,
		newname, devname)) {
		log_fatal("couldn't send command/get its response");
		return (0);
	}

	/* get response packet */
	log_info("checking command answer");
	if (response.type != p7_pt_ack && response.type != p7_pt_error) {
		p7_error = p7_error_unknown;
		log_fatal("received an invalid answer");
		return (0);
	}
	/* - check it - */
	if (response.type == p7_pt_error) {
		switch (response.error.code) {
		/* overwrite impossible */
		case p7_ec_overwrite_noresponse:
		case p7_ec_overwrite_impossible:
			p7_error = p7_error_overwrite_impossible;
			log_error("overwrite impossible");
			return (0);

		/* memory full */
		case p7_ec_fullmem:
			p7_error = p7_error_fullmem;
			log_error("distant memory is full");
			return (0);

		/* resend error - just here to stfu the warning */
		default:
			p7_error = p7_error_unknown;
			return (0);
		}
	}

	/* we're done */
	return (1);
}
