/* ************************************************************************** */
/*                                       _____           _                    */
/*  protocol/delfile.c                  |_   _|__  _   _| |__   ___ _   _     */
/*  | Project : libp7                     | |/ _ \| | | | '_ \ / _ \ | | |    */
/*                                        | | (_) | |_| | | | |  __/ |_| |    */
/*  By: thomas <thomas@touhey.fr>         |_|\___/ \__,_|_| |_|\___|\__, |.fr */
/*  Last updated: 2016/08/22 16:02:52                               |___/     */
/*                                                                            */
/* ************************************************************************** */

#include <string.h>
#include <libp7/internals.h>

/**
 *	p7_delfile:
 *	Deletes a distant file.
 *
 *	@arg	dirname		the directory name
 *	@arg	filename	the file name
 *	@arg	devname		the device name
 *	@return				if it worked
 */

int p7_delfile(char *dirname, char *filename, char *devname)
{
	/* check filename */
	if (!p7_validate_filename(filename)) {
		p7_error = p7_error_filename;
		log_error("sent filename was crappy, returning error to user");
		return (0);
	}

	/* check dirname */
	if (dirname && !p7_validate_dirname(dirname)) {
		p7_error = p7_error_dirname;
		log_error("sent dirname was crappy, returning error to user");
		return (0);
	}

	/* send command packet */
	log_info("sending command");
	if (!p7_send_cmdfls_delfile(dirname, filename, devname)) {
		log_fatal("couldn't send command/get its response");
		return (0);
	}

	/* get response packet */
	log_info("checking command answer");
	if (response.type != p7_pt_ack && response.type != p7_pt_error) {
		p7_error = p7_error_unknown;
		log_fatal("received an invalid answer");
		return (0);
	}
	/* - check it - */
	if (response.type == p7_pt_error
	 && response.error.code == p7_ec_overwrite_impossible) {
		p7_error = p7_error_overwrite_impossible;
		log_fatal("overwrite impossible error received");
		return (0);
	}

	/* we're done */
	return (1);
}
