/* ************************************************************************** */
/*                                       _____           _                    */
/*  utils/checksum.c                    |_   _|__  _   _| |__   ___ _   _     */
/*  | Project : libp7                     | |/ _ \| | | | '_ \ / _ \ | | |    */
/*                                        | | (_) | |_| | | | |  __/ |_| |    */
/*  By: thomas <thomas@touhey.fr>         |_|\___/ \__,_|_| |_|\___|\__, |.fr */
/*  Last updated: 2016/08/16 17:02:54                               |___/     */
/*                                                                            */
/* ************************************************************************** */

#include <libp7/internals.h>

/**
 *	p7_checksum:
 *	Returns the checksum of a packet
 *
 *	The checksum is an unsigned integer that can fit in 8 bits.
 *
 *	@arg	packet		pointer to the packet
 *	@arg	size		the packet size (in bytes)
 *	@return				the checksum
 */

unsigned int p7_checksum(uint8_t *packet, unsigned int size)
{
	unsigned int sum = 0;
	packet++, size -= 3; /* remove type and checksum fields */
	while (size--) {
		sum += *packet++;
	}

	sum = ~sum + 1; sum %= 256;
	return (sum);
}
